@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2013-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,28 +12,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2013-2018
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2013-2015
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2013-2020
-# - Martin Barisits <martin.barisits@cern.ch>, 2013-2020
-# - Yun-Pin Sun <winter0128@gmail.com>, 2013
-# - Thomas Beermann <thomas.beermann@cern.ch>, 2013
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014-2021
-# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2014-2018
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - Eric Vaandering <ewv@fnal.gov>, 2018-2020
-# - asket <asket.agarwal96@gmail.com>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Aristeidis Fkiaras <aristeidis.fkiaras@cern.ch>, 2020
-# - Alan Malta Rodrigues <alan.malta@cern.ch>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020-2021
 
 from __future__ import print_function
 
+from datetime import datetime
 from json import dumps, loads
 
 from requests.status_codes import codes
@@ -51,36 +33,40 @@ class DIDClient(BaseClient):
     DIDS_BASEURL = 'dids'
     ARCHIVES_BASEURL = 'archives'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None,
-                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(DIDClient, self).__init__(rucio_host, auth_host, account, ca_cert,
-                                        auth_type, creds, timeout, user_agent, vo=vo)
-
-    def list_dids(self, scope, filters, type='collection', long=False, recursive=False):
+    def list_dids(self, scope, filters, did_type='collection', long=False, recursive=False):
         """
         List all data identifiers in a scope which match a given pattern.
 
         :param scope: The scope name.
-        :param filters: A dictionary of key/value pairs like {'type': 'dataset', 'scope': 'test'}.
-        :param type: The type of the did: 'all'(container, dataset or file)|'collection'(dataset or container)|'dataset'|'container'|'file'
+        :param filters: A nested dictionary of key/value pairs like [{'key1': 'value1', 'key2.lte': 'value2'}, {'key3.gte, 'value3'}].
+                        Keypairs in the same dictionary are AND'ed together, dictionaries are OR'ed together. Keys should be suffixed
+                        like <key>.<operation>, e.g. key1 >= value1 is equivalent to {'key1.gte': value}, where <operation> belongs to one
+                        of the set {'lte', 'gte', 'gt', 'lt', 'ne' or ''}. Equivalence doesn't require an operator.
+        :param did_type: The type of the did: 'all'(container, dataset or file)|'collection'(dataset or container)|'dataset'|'container'|'file'
         :param long: Long format option to display more information for each DID.
         :param recursive: Recursively list DIDs content.
         """
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), 'dids', 'search'])
-        payload = {}
 
-        for k, v in list(filters.items()):
-            if k in ('created_before', 'created_after'):
-                payload[k] = date_to_str(v)
-            else:
-                payload[k] = v
-        payload['long'] = long
-        payload['type'] = type
-        payload['recursive'] = recursive
+        # stringify dates.
+        if isinstance(filters, dict):   # backwards compatability for filters as single {}
+            filters = [filters]
+        for or_group in filters:
+            for key, value in or_group.items():
+                if isinstance(value, datetime):
+                    or_group[key] = date_to_str(value)
+
+        payload = {
+            'type': did_type,
+            'filters': filters,
+            'long': long,
+            'recursive': recursive
+        }
 
         url = build_url(choice(self.list_hosts), path=path, params=payload)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
+
         if r.status_code == codes.ok:
             dids = self._load_json_data(r)
             return dids
@@ -88,30 +74,40 @@ class DIDClient(BaseClient):
             exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
             raise exc_cls(exc_msg)
 
-    def list_dids_extended(self, scope, filters, type='collection', long=False, recursive=False):
+    def list_dids_extended(self, scope, filters, did_type='collection', long=False, recursive=False):
         """
-        List all data identifiers in a scope which match a given pattern. Extended version that goes through plugin mechanism.
+        List all data identifiers in a scope which match a given pattern.
 
         :param scope: The scope name.
-        :param filters: A dictionary of key/value pairs like {'type': 'dataset', 'scope': 'test'}.
-        :param type: The type of the did: 'all'(container, dataset or file)|'collection'(dataset or container)|'dataset'|'container'|'file'
+        :param filters: A nested dictionary of key/value pairs like [{'key1': 'value1', 'key2.lte': 'value2'}, {'key3.gte, 'value3'}].
+                        Keypairs in the same dictionary are AND'ed together, dictionaries are OR'ed together. Keys should be suffixed
+                        like <key>.<operation>, e.g. key1 >= value1 is equivalent to {'key1.gte': value}, where <operation> belongs to one
+                        of the set {'lte', 'gte', 'gt', 'lt', 'ne' or ''}. Equivalence doesn't require an operator.
+        :param did_type: The type of the did: 'all'(container, dataset or file)|'collection'(dataset or container)|'dataset'|'container'|'file'
         :param long: Long format option to display more information for each DID.
         :param recursive: Recursively list DIDs content.
         """
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), 'dids', 'search_extended'])
-        payload = {}
 
-        for k, v in list(filters.items()):
-            if k in ('created_before', 'created_after'):
-                payload[k] = date_to_str(v)
-            else:
-                payload[k] = v
-        payload['long'] = long
-        payload['type'] = type
-        payload['recursive'] = recursive
+        # stringify dates.
+        if isinstance(filters, dict):   # backwards compatability for filters as single {}
+            filters = [filters]
+        for or_group in filters:
+            for key, value in or_group.items():
+                if isinstance(value, datetime):
+                    or_group[key] = date_to_str(value)
+
+        payload = {
+            'type': did_type,
+            'filters': filters,
+            'long': long,
+            'recursive': recursive
+        }
 
         url = build_url(choice(self.list_hosts), path=path, params=payload)
-        r = self._send_request(url, type='GET')
+
+        r = self._send_request(url, type_='GET')
+
         if r.status_code == codes.ok:
             dids = self._load_json_data(r)
             return dids
@@ -119,7 +115,7 @@ class DIDClient(BaseClient):
             exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
             raise exc_cls(exc_msg)
 
-    def add_did(self, scope, name, type, statuses=None, meta=None, rules=None, lifetime=None, dids=None, rse=None):
+    def add_did(self, scope, name, did_type, statuses=None, meta=None, rules=None, lifetime=None, dids=None, rse=None):
         """
         Add data identifier for a dataset or container.
 
@@ -136,7 +132,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name)])
         url = build_url(choice(self.list_hosts), path=path)
         # Build json
-        data = {'type': type}
+        data = {'type': did_type}
         if statuses:
             data['statuses'] = statuses
         if meta:
@@ -149,7 +145,7 @@ class DIDClient(BaseClient):
             data['dids'] = dids
         if rse:
             data['rse'] = rse
-        r = self._send_request(url, type='POST', data=render_json(**data))
+        r = self._send_request(url, type_='POST', data=render_json(**data))
         if r.status_code == codes.created:
             return True
         else:
@@ -162,7 +158,7 @@ class DIDClient(BaseClient):
         """
         path = '/'.join([self.DIDS_BASEURL])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=render_json_list(dids))
+        r = self._send_request(url, type_='POST', data=render_json_list(dids))
         if r.status_code == codes.created:
             return True
         else:
@@ -182,7 +178,7 @@ class DIDClient(BaseClient):
         :param files: The content.
         :param rse: The RSE name when registering replicas.
         """
-        return self.add_did(scope=scope, name=name, type='DATASET',
+        return self.add_did(scope=scope, name=name, did_type='DATASET',
                             statuses=statuses, meta=meta, rules=rules,
                             lifetime=lifetime, dids=files, rse=rse)
 
@@ -205,7 +201,7 @@ class DIDClient(BaseClient):
         :param rules: Replication rules associated with the data identifier. A list of dictionaries, e.g., [{'copies': 2, 'rse_expression': 'TIERS1'}, ].
         :param lifetime: DID's lifetime (in seconds).
         """
-        return self.add_did(scope=scope, name=name, type='CONTAINER', statuses=statuses, meta=meta, rules=rules, lifetime=lifetime)
+        return self.add_did(scope=scope, name=name, did_type='CONTAINER', statuses=statuses, meta=meta, rules=rules, lifetime=lifetime)
 
     def add_containers(self, cnts):
         """
@@ -229,7 +225,7 @@ class DIDClient(BaseClient):
         data = {'dids': dids}
         if rse:
             data['rse'] = rse
-        r = self._send_request(url, type='POST', data=render_json(**data))
+        r = self._send_request(url, type_='POST', data=render_json(**data))
         if r.status_code == codes.created:
             return True
         else:
@@ -248,7 +244,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'dids'])
         url = build_url(choice(self.list_hosts), path=path)
         data = {'dids': dids}
-        r = self._send_request(url, type='DEL', data=render_json(**data))
+        r = self._send_request(url, type_='DEL', data=render_json(**data))
         if r.status_code == codes.ok:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -267,7 +263,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, 'attachments'])
         url = build_url(choice(self.list_hosts), path=path)
         data = {'ignore_duplicate': ignore_duplicate, 'attachments': attachments}
-        r = self._send_request(url, type='POST', data=dumps(data))
+        r = self._send_request(url, type_='POST', data=dumps(data))
         if r.status_code in (codes.ok, codes.no_content, codes.created):
             return True
 
@@ -360,7 +356,7 @@ class DIDClient(BaseClient):
 
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'dids'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -376,7 +372,7 @@ class DIDClient(BaseClient):
 
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'dids', 'history'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -397,7 +393,7 @@ class DIDClient(BaseClient):
             payload['long'] = True
         url = build_url(choice(self.list_hosts), path=path, params=payload)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -417,7 +413,7 @@ class DIDClient(BaseClient):
         if dynamic:
             path += '?dynamic=True'
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         else:
@@ -435,7 +431,7 @@ class DIDClient(BaseClient):
         url = build_url(choice(self.list_hosts), path=path)
         payload = {}
         payload['plugin'] = plugin
-        r = self._send_request(url, type='GET', params=payload)
+        r = self._send_request(url, type_='GET', params=payload)
         if r.status_code == codes.ok:
             meta = self._load_json_data(r)
             return next(meta)
@@ -452,7 +448,7 @@ class DIDClient(BaseClient):
         data = {'dids': dids, 'inherit': inherit}
         path = '/'.join([self.DIDS_BASEURL, 'bulkmeta'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps(data))
+        r = self._send_request(url, type_='POST', data=dumps(data))
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -471,7 +467,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'meta', key])
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'value': value, 'recursive': recursive})
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return True
         else:
@@ -491,7 +487,24 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'meta'])
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps({'meta': meta, 'recursive': recursive})
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
+        if r.status_code == codes.created:
+            return True
+        else:
+            exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
+            raise exc_cls(exc_msg)
+
+    def set_dids_metadata_bulk(self, dids, recursive=False):
+        """
+        Set metadata to a list of data identifiers.
+
+        :param dids: A list of dids including metadata, i.e. [['scope': scope1, 'name': name1, 'meta': {key1: value1, key2: value2}] .
+        :param recursive: Option to propagate the metadata update to content.
+        """
+        path = '/'.join([self.DIDS_BASEURL, 'bulkdidsmeta'])
+        url = build_url(choice(self.list_hosts), path=path)
+        data = dumps({'dids': dids, 'recursive': recursive})
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return True
         else:
@@ -509,7 +522,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'status'])
         url = build_url(choice(self.list_hosts), path=path)
         data = dumps(kwargs)
-        r = self._send_request(url, type='PUT', data=data)
+        r = self._send_request(url, type_='PUT', data=data)
         if r.status_code in (codes.ok, codes.no_content, codes.created):
             return True
 
@@ -536,7 +549,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'meta'])
         url = build_url(choice(self.list_hosts), path=path, params={'key': key})
 
-        r = self._send_request(url, type='DEL')
+        r = self._send_request(url, type_='DEL')
         if r.status_code == codes.ok:
             return True
         else:
@@ -553,7 +566,7 @@ class DIDClient(BaseClient):
 
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'rules'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -570,7 +583,7 @@ class DIDClient(BaseClient):
 
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'associated_rules'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -587,7 +600,7 @@ class DIDClient(BaseClient):
 
         path = '/'.join([self.DIDS_BASEURL, guid, 'guid'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -611,7 +624,7 @@ class DIDClient(BaseClient):
             payload['recursive'] = True
         url = build_url(choice(self.list_hosts), path=path, params=payload)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -629,7 +642,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.DIDS_BASEURL, quote_plus(scope), quote_plus(name), 'parents'])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         else:
@@ -649,7 +662,7 @@ class DIDClient(BaseClient):
         """
         path = '/'.join([self.DIDS_BASEURL, quote_plus(input_scope), quote_plus(input_name), quote_plus(output_scope), quote_plus(output_name), str(nbfiles), 'sample'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps({}))
+        r = self._send_request(url, type_='POST', data=dumps({}))
         if r.status_code == codes.created:
             return True
         else:
@@ -664,7 +677,7 @@ class DIDClient(BaseClient):
         """
         path = '/'.join([self.DIDS_BASEURL, 'resurrect'])
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=dumps(dids))
+        r = self._send_request(url, type_='POST', data=dumps(dids))
         if r.status_code == codes.created:
             return True
         else:
@@ -678,7 +691,7 @@ class DIDClient(BaseClient):
         :param dids: A list of dids.
         """
         url = build_url(choice(self.list_hosts), path='tmp_dids')
-        r = self._send_request(url, type='POST', data=dumps(dids))
+        r = self._send_request(url, type_='POST', data=dumps(dids))
         if r.status_code == codes.created:
             return True
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -694,7 +707,7 @@ class DIDClient(BaseClient):
         path = '/'.join([self.ARCHIVES_BASEURL, quote_plus(scope), quote_plus(name), 'files'])
         url = build_url(choice(self.list_hosts), path=path)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return self._load_json_data(r)
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
@@ -712,7 +725,7 @@ class DIDClient(BaseClient):
             payload['scope'] = scope
         payload['select'] = dumps(select)
         url = build_url(choice(self.list_hosts), path=path, params=payload)
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return loads(next(self._load_json_data(r)))
         else:
