@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,11 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2021
 
 from requests.status_codes import codes
 
@@ -30,11 +25,6 @@ class ExportClient(BaseClient):
 
     EXPORT_BASEURL = 'export'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None,
-                 auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(ExportClient, self).__init__(rucio_host, auth_host, account, ca_cert,
-                                           auth_type, creds, timeout, user_agent, vo=vo)
-
     def export_data(self, distance=True):
         """
         Export RSE data (RSE, settings, attributes and distance).
@@ -46,7 +36,7 @@ class ExportClient(BaseClient):
         path = '/'.join([self.EXPORT_BASEURL])
         url = build_url(choice(self.list_hosts), path=path, params=payload)
 
-        r = self._send_request(url, type='GET')
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return parse_response(r.text)
         else:
