@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2012-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,17 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - asket <asket.agarwal96@gmail.com>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2021
 
 from json import dumps, loads
 
@@ -40,9 +29,6 @@ class MetaClient(BaseClient):
 
     META_BASEURL = 'meta'
 
-    def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=600, user_agent='rucio-clients', vo=None):
-        super(MetaClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout, user_agent, vo=vo)
-
     def add_key(self, key, key_type, value_type=None, value_regexp=None):
         """
         Sends the request to add a new key.
@@ -62,7 +48,7 @@ class MetaClient(BaseClient):
                       'value_regexp': value_regexp,
                       'key_type': key_type})
 
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
 
         if r.status_code == codes.created:
             return True
@@ -116,7 +102,7 @@ class MetaClient(BaseClient):
         path = '/'.join([self.META_BASEURL, quote_plus(key)]) + '/'
         data = dumps({'value': value})
         url = build_url(choice(self.list_hosts), path=path)
-        r = self._send_request(url, type='POST', data=data)
+        r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
             return True
         else:
@@ -140,12 +126,12 @@ class MetaClient(BaseClient):
         """
         pass
 
-    def update_key(self, key, type=None, regepx=None):
+    def update_key(self, key, type_=None, regexp=None):
         """
         Update a key.
 
         :param key: the name for key.
-        :param type: the type of the value, if defined.
+        :param type_: the type of the value, if defined.
         :param regexp: the regular expression that values should match, if defined.
         """
         pass
