@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2013-2021 CERN
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,22 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Martin Barisits <martin.barisits@cern.ch>, 2013-2018
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2013-2018
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2014-2015
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2015
-# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
-# - dciangot <diego.ciangottini@cern.ch>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Eric Vaandering <ewv@fnal.gov>, 2020
-# - Patrick Austin <patrick.austin@stfc.ac.uk>, 2020
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Radu Carpa <radu.carpa@cern.ch>, 2021
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2021
-# - Joel Dierkes <joel.dierkes@cern.ch>, 2021
 
 from json import dumps, loads
 
@@ -107,18 +91,16 @@ class RuleClient(BaseClient):
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
         raise exc_cls(exc_msg)
 
-    def get_replication_rule(self, rule_id, estimate_ttc=False):
+    def get_replication_rule(self, rule_id):
         """
         Get a replication rule.
 
         :param rule_id:  The id of the rule to be retrieved.
-        :param estimate_ttc: bool, if rule_info should return ttc information
         :raises:         RuleNotFound
         """
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
-        data = dumps({'estimate_ttc': estimate_ttc})
-        r = self._send_request(url, type_='GET', data=data)
+        r = self._send_request(url, type_='GET')
         if r.status_code == codes.ok:
             return next(self._load_json_data(r))
         else:
@@ -157,14 +139,13 @@ class RuleClient(BaseClient):
         exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code, data=r.content)
         raise exc_cls(exc_msg)
 
-    def move_replication_rule(self, rule_id, rse_expression, activity, source_replica_expression):
+    def move_replication_rule(self, rule_id, rse_expression, override):
         """
         Move a replication rule to another RSE and, once done, delete the original one.
 
         :param rule_id:                    Rule to be moved.
         :param rse_expression:             RSE expression of the new rule.
-        :param activity:                   Activity of the new rule.
-        :param source_replica_expression:  Source-Replica-Expression of the new rule.
+        :param override:                   Configurations to update for the new rule.
         :raises:                           RuleNotFound, RuleReplaceFailed
         """
 
@@ -173,8 +154,7 @@ class RuleClient(BaseClient):
         data = dumps({
             'rule_id': rule_id,
             'rse_expression': rse_expression,
-            'activity': activity,
-            'source_replica_expression': source_replica_expression
+            'override': override,
         })
         r = self._send_request(url, type_='POST', data=data)
         if r.status_code == codes.created:
