@@ -1,21 +1,17 @@
-"""
- Copyright European Organization for Nuclear Research (CERN)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- You may not use this file except in compliance with the License.
- You may obtain a copy of the License at
- http://www.apache.org/licenses/LICENSE-2.0
-
- Authors:
- - Cedric Serfon <cedric.serfon@cern.ch>, 2016-2018
- - Martin Barisits <martin.barisits@cern.ch>, 2017-2018
- - Vincent Garonne <vgaronne@gmail.com>, 2017-2018
- - Brian Bockelman <bbockelm@cse.unl.edu>, 2017
- - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
- - Thomas Beermann <thomas.beermann@cern.ch>, 2021
-
- PY3K COMPATIBLE
-"""
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2016
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 import json
 import os
@@ -35,7 +31,7 @@ from rucio.common.config import config_get
 from rucio.common.exception import UndefinedPolicy
 
 REGION = make_region().configure('dogpile.cache.memory',
-                                 expiration_time=1800)
+                                 expiration_time=900)
 
 
 def get_policy():
