@@ -1,4 +1,5 @@
-# Copyright 2017-2020 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2017
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,14 +12,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Vincent Garonne <vincent.garonne@cern.ch>, 2017-2018
-# - Edgar Fajardo <emfajard@ucsd.edu>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2019
-# - James Perry <j.perry@epcc.ed.ac.uk>, 2019-2020
-# - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
+
+from os import environ
 
 try:
     from ConfigParser import NoOptionError, NoSectionError
@@ -36,7 +31,7 @@ schema_modules = {}
 scope_name_regexps = []
 
 try:
-    multivo = config.config_get_bool('common', 'multi_vo')
+    multivo = config.config_get_bool('common', 'multi_vo', check_config_table=False)
 except (NoOptionError, NoSectionError):
     multivo = False
 
@@ -48,11 +43,14 @@ if not multivo:
 
     if config.config_has_section('policy'):
         try:
-            POLICY = config.config_get('policy', 'package') + ".schema"
+            if 'RUCIO_POLICY_PACKAGE' in environ:
+                POLICY = environ['RUCIO_POLICY_PACKAGE'] + ".schema"
+            else:
+                POLICY = config.config_get('policy', 'package', check_config_table=False) + ".schema"
         except (NoOptionError, NoSectionError):
             # fall back to old system for now
             try:
-                POLICY = config.config_get('policy', 'schema')
+                POLICY = config.config_get('policy', 'schema', check_config_table=False)
             except (NoOptionError, NoSectionError):
                 POLICY = GENERIC_FALLBACK
             POLICY = 'rucio.common.schema.' + POLICY.lower()
@@ -72,11 +70,15 @@ def load_schema_for_vo(vo):
     GENERIC_FALLBACK = 'generic_multi_vo'
     if config.config_has_section('policy'):
         try:
-            POLICY = config.config_get('policy', 'package-' + vo) + ".schema"
+            env_name = 'RUCIO_POLICY_PACKAGE_' + vo.upper()
+            if env_name in environ:
+                POLICY = environ[env_name] + ".schema"
+            else:
+                POLICY = config.config_get('policy', 'package-' + vo, check_config_table=False) + ".schema"
         except (NoOptionError, NoSectionError):
             # fall back to old system for now
             try:
-                POLICY = config.config_get('policy', 'schema')
+                POLICY = config.config_get('policy', 'schema', check_config_table=False)
             except (NoOptionError, NoSectionError):
                 POLICY = GENERIC_FALLBACK
             POLICY = 'rucio.common.schema.' + POLICY.lower()
