@@ -1,4 +1,5 @@
-# Copyright 2012-2019 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright CERN since 2012
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,28 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Ralph Vigne <ralph.vigne@cern.ch>, 2012-2014
-# - Vincent Garonne <vgaronne@gmail.com>, 2012-2016
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2013-2019
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2020
-# - Wen Guan <wguan.icedew@gmail.com>, 2014-2017
-# - Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
-# - Tobias Wegner <twegner@cern.ch>, 2017
-# - Brian Bockelman <bbockelm@cse.unl.edu>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2018
-# - Nicolo Magini <Nicolo.Magini@cern.ch>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
-# - James Clark <james.clark@physics.gatech.edu>, 2019
-# - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Eli Chadwick, <eli.chadwick@stfc.ac.uk>, 2020
-# - Luca Scotto Lavina, <scotto@lpnhe.in2p3.fr>, 2021
-# - Thomas Beermann, <thomas.beermann@cern.ch>, 2021
-# - James Perry <j.perry@epcc.ed.ac.uk>, 2021
-# - Lionel Schwarz <lionel.schwarz@in2p3.fr>, 2021
-#
-# PY3K COMPATIBLE
 
 """
 This module defines the base class for implementing a transfer protocol,
@@ -53,6 +32,7 @@ except ImportError:
 from six import string_types
 
 from rucio.common import config, exception
+from rucio.common.utils import register_policy_package_algorithms
 from rucio.rse import rsemanager
 
 if getattr(rsemanager, 'CLIENT_MODE', None):
@@ -267,31 +247,6 @@ class RSEDeterministicTranslation(object):
 
         cls._DEFAULT_LFN2PFN = config.get_lfn2pfn_algorithm_default()
 
-    def try_importing_policy(self, vo=None):
-        import importlib
-        try:
-            package = config.config_get('policy', 'package' + ('' if not vo else '-' + vo['vo']))
-            module = importlib.import_module(package)
-            if hasattr(module, 'get_lfn2pfn_algorithms'):
-                RSEDeterministicTranslation._LFN2PFN_ALGORITHMS.update(module.get_lfn2pfn_algorithms())
-        except (NoOptionError, NoSectionError, ImportError):
-            pass
-
-    def query_policy_packages(self):
-        from rucio.core.vo import list_vos
-        try:
-            multivo = config.config_get_bool('common', 'multi_vo')
-        except (NoOptionError, NoSectionError):
-            multivo = False
-        if not multivo:
-            # single policy package
-            self.try_importing_policy()
-        else:
-            # policy package per VO
-            vos = list_vos()
-            for vo in vos:
-                self.try_importing_policy(vo)
-
     def path(self, scope, name):
         """ Transforms the logical file name into a PFN's path.
 
@@ -302,7 +257,7 @@ class RSEDeterministicTranslation(object):
         """
         # on first call, register any lfn2pfn algorithms from the policy package(s) (server only)
         if getattr(rsemanager, 'SERVER_MODE', None) and not self.loaded_policy_modules:
-            self.query_policy_packages()
+            register_policy_package_algorithms('lfn2pfn', RSEDeterministicTranslation._LFN2PFN_ALGORITHMS)
             self.loaded_policy_modules = True
 
         algorithm = self.rse_attributes.get('lfn2pfn_algorithm', 'default')
@@ -450,12 +405,15 @@ class RSEProtocol(object):
             while '//' in parsed.path:
                 parsed = parsed._replace(path=parsed.path.replace('//', '/'))
             path = parsed.path
+            prefix = self.attributes['prefix']
+            while '//' in prefix:
+                prefix = prefix.replace('//', '/')
 
             # Protect against 'lazy' defined prefixes for RSEs in the repository
-            if not self.attributes['prefix'].startswith('/'):
-                self.attributes['prefix'] = '/' + self.attributes['prefix']
-            if not self.attributes['prefix'].endswith('/'):
-                self.attributes['prefix'] += '/'
+            if not prefix.startswith('/'):
+                prefix = '/' + prefix
+            if not prefix.endswith('/'):
+                prefix += '/'
 
             if self.attributes['hostname'] != hostname:
                 if self.attributes['hostname'] != 'localhost':  # In the database empty hostnames are replaced with localhost but for some URIs (e.g. file) a hostname is not included
@@ -464,13 +422,12 @@ class RSEProtocol(object):
             if self.attributes['port'] != port:
                 raise exception.RSEFileNameNotSupported('Invalid port: provided \'%s\', expected \'%s\'' % (port, self.attributes['port']))
 
-            if not path.startswith(self.attributes['prefix']):
-                raise exception.RSEFileNameNotSupported('Invalid prefix: provided \'%s\', expected \'%s\'' % ('/'.join(path.split('/')[0:len(self.attributes['prefix'].split('/')) - 1]),
-                                                                                                              self.attributes['prefix']))  # len(...)-1 due to the leading '/
+            if not path.startswith(prefix):
+                raise exception.RSEFileNameNotSupported('Invalid prefix: provided \'%s\', expected \'%s\'' % ('/'.join(path.split('/')[0:len(prefix.split('/')) - 1]),
+                                                                                                              prefix))  # len(...)-1 due to the leading '/
 
             # Spliting parsed.path into prefix, path, filename
-            prefix = self.attributes['prefix']
-            path = path.partition(self.attributes['prefix'])[2]
+            path = path.partition(prefix)[2]
             name = path.split('/')[-1]
             path = '/'.join(path.split('/')[:-1])
             if not path.startswith('/'):
