@@ -149,7 +149,7 @@ class Default(protocol.RSEProtocol):
     def connect(self, credentials={}):
         """ Establishes the actual connection to the referred RSE.
 
-            :param credentials Provides information to establish a connection
+            :param credentials: Provides information to establish a connection
                 to the referred storage system. For WebDAV connections these are
                 ca_cert, cert, auth_type, timeout
 
@@ -224,7 +224,7 @@ class Default(protocol.RSEProtocol):
     def exists(self, pfn):
         """ Checks if the requested file is known by the referred RSE.
 
-            :param pfn Physical file name
+            :param pfn: Physical file name
 
             :returns: True if the file exists, False if it doesn't
 
@@ -248,8 +248,8 @@ class Default(protocol.RSEProtocol):
     def get(self, pfn, dest='.', transfer_timeout=None):
         """ Provides access to files stored inside connected the RSE.
 
-            :param pfn Physical file name of requested file
-            :param dest Name and path of the files when stored at the client
+            :param pfn: Physical file name of requested file
+            :param dest: Name and path of the files when stored at the client
             :param transfer_timeout: Transfer timeout (in seconds) - dummy
 
             :raises DestinationNotAccessible, ServiceUnavailable, SourceNotFound, RSEAccessDenied
@@ -285,8 +285,8 @@ class Default(protocol.RSEProtocol):
     def put(self, source, target, source_dir=None, transfer_timeout=None, progressbar=False):
         """ Allows to store files inside the referred RSE.
 
-            :param source Physical file name
-            :param target Name of the file on the storage system e.g. with prefixed scope
+            :param source: Physical file name
+            :param target: Name of the file on the storage system e.g. with prefixed scope
             :param source_dir Path where the to be transferred files are stored in the local file system
             :param transfer_timeout Transfer timeout (in seconds) - dummy
 
@@ -338,7 +338,7 @@ class Default(protocol.RSEProtocol):
     def rename(self, pfn, new_pfn):
         """ Allows to rename a file stored inside the connected RSE.
 
-            :param pfn      Current physical file name
+            :param pfn:      Current physical file name
             :param new_pfn  New physical file name
 
             :raises DestinationNotAccessible, ServiceUnavailable, SourceNotFound, RSEAccessDenied
@@ -381,7 +381,7 @@ class Default(protocol.RSEProtocol):
     def delete(self, pfn):
         """ Deletes a file from the connected RSE.
 
-            :param pfn Physical file name
+            :param pfn: Physical file name
 
             :raises ServiceUnavailable, SourceNotFound, RSEAccessDenied, ResourceTemporaryUnavailable
         """
@@ -407,7 +407,7 @@ class Default(protocol.RSEProtocol):
     def mkdir(self, directory):
         """ Internal method to create directories
 
-            :param directory Name of the directory that needs to be created
+            :param directory: Name of the directory that needs to be created
 
             :raises DestinationNotAccessible, ServiceUnavailable, SourceNotFound, RSEAccessDenied
         """
@@ -431,7 +431,7 @@ class Default(protocol.RSEProtocol):
     def ls(self, filename):
         """ Internal method to list files/directories
 
-            :param filename Name of the directory that needs to be created
+            :param filename: Name of the directory that needs to be created
 
             :raises DestinationNotAccessible, ServiceUnavailable, SourceNotFound, RSEAccessDenied
         """
