@@ -721,8 +721,8 @@ def _retry_protocol_stat(protocol, pfn):
     """
     try to stat file, on fail try again 1s, 2s, 4s, 8s, 16s, 32s later. Fail is all fail
 
-    :param protocol     The protocol to use to reach this file
-    :param pfn          Physical file name of the target for the protocol stat
+    :param protocol:     The protocol to use to reach this file
+    :param pfn:          Physical file name of the target for the protocol stat
     """
     retries = config_get_int('client', 'protocol_stat_retries', raise_exception=False, default=6)
     for attempt in range(retries):
