@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 CERN
+# Copyright CERN since 2021
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#
-# Authors:
-# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2021
-# - Martin Barisits <martin.barisits@cern.ch>, 2021
 
 from __future__ import print_function
 
@@ -50,7 +46,6 @@ clients_requirements_table = {
     'sftp': ['pysftp'],
     # 'gfal2': ['gfal2-python'],
     'dumper': [
-        'bz2file',
         # 'gfal2-python',
         'python-magic',
     ],
@@ -80,7 +75,6 @@ server_requirements_table = {
     'install_requires': clients_requirements_table['install_requires'] + [
         'argcomplete',
         'boto',
-        'bz2file',
         'python-magic',
         'paramiko',
         'boto3',
@@ -95,12 +89,12 @@ server_requirements_table = {
         'oauth2client',
         'retrying',
         'redis',
-        'numpy',
         'flask',
         'oic',
         'prometheus_client',
     ],
     'oracle': ['cx_oracle'],
+    'mongo': ['pymongo'],
     'postgresql': ['psycopg2-binary'],
     'mysql': ['PyMySQL'],
     'kerberos': [
